@@ -1,3 +1,4 @@
+package urpm::bug_report;
 
 use strict;
 use urpm;
@@ -70,7 +71,6 @@ sub copy_requested {
 
 1;
 
-__END__
 
 =back
 
